@@ -4,19 +4,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -97,9 +96,11 @@ static int create_version = 2;	/* format version of newly created tag file */
 int
 gpath_open(const char *dbpath, int mode)
 {
-	if (opened++ > 0) {
+	if (opened > 0) {
 		if (mode != _mode)
 			die("duplicate open with different mode.");
+		opened++;
+		return 0;
 	}
 	/*
 	 * We create GPATH just first time.
@@ -127,6 +128,7 @@ gpath_open(const char *dbpath, int mode)
 		else if (format_version < support_version)
                         die("GPATH seems older format. Please remake tag files."); 
 	}
+	opened++;
 	return 0;
 }
 /*
@@ -140,7 +142,7 @@ gpath_open(const char *dbpath, int mode)
 void
 gpath_put(const char *path, int type)
 {
-	char fid[32];
+	char fid[MAXFIDLEN];
 	STATIC_STRBUF(sb);
 
 	assert(opened > 0);
@@ -246,8 +248,9 @@ gpath_nextkey(void)
 void
 gpath_close(void)
 {
-	char fid[32];
+	char fid[MAXFIDLEN];
 
+	assert(opened > 0);
 	if (--opened > 0)
 		return;
 	if (_mode == 1 && created) {
@@ -285,7 +288,7 @@ gpath_close(void)
 GFIND *
 gfind_open(const char *dbpath, const char *local, int target)
 {
-	GFIND *gfind = (GFIND *)check_malloc(sizeof(GFIND));
+	GFIND *gfind = (GFIND *)check_calloc(sizeof(GFIND), 1);
 
 	gfind->dbop = dbop_open(makepath(dbpath, dbname(GPATH), NULL), 0, 0, 0);
 	if (gfind->dbop == NULL)
