@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2008
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2008, 2011
  *	Tama Communications Corporation
  * #ifdef __DJGPP__
  * Contributed by Jason Hood <jadoxa@yahoo.com.au>, 2001.
@@ -214,7 +214,7 @@ makedirectories(const char *base, const char *rest, int verbose)
 		if (!test("d", p)) {
 			if (verbose)
 				fprintf(stderr, " Making directory '%s'.\n", p);
-#if (defined(_WIN32) && !defined(__CYGWIN__)) || defined(__DJGPP__)
+#if defined(_WIN32) && !defined(__CYGWIN__)
 			if (mkdir(p) < 0) {
 #else
 			if (mkdir(p, 0775) < 0) {
@@ -229,3 +229,13 @@ makedirectories(const char *base, const char *rest, int verbose)
 	strbuf_close(sb);
 	return 0;
 }
+/*
+ * trimpath: trim path name
+ */
+const char *
+trimpath(const char *path)
+{
+	if (*path == '.' && *(path + 1) == '/')
+		path += 2;
+	return path;
+}
